<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package StartNext
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function startnext_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'startnext_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function startnext_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'startnext_pingback_header' );


// Preloader
if ( ! function_exists( 'startnext_preloader' ) ) :
	function startnext_preloader() {
		global $startnext_opt;

		if( isset( $startnext_opt['enable_preloader'] ) ):
			$is_preloader = $startnext_opt['enable_preloader'];
		else:
			$is_preloader = true;
		endif;

		//$is_preloader       = !empty($startnext_opt['enable_preloader']) ? $startnext_opt['enable_preloader'] : '1';

        $preloader_style    = !empty($startnext_opt['preloader_style']) ? $startnext_opt['preloader_style'] : 'circle-spin';

        if( $is_preloader == true ):
            if ( defined( 'ELEMENTOR_VERSION' ) ) :
                if (\Elementor\Plugin::$instance->preview->is_preview_mode()) :
                    echo '';
                else:
                    if ( $preloader_style == 'text' ) :
                        if (!empty( $startnext_opt['loading_text'] ) ) : ?>
                            <div class="preloader">
								<p class="text-center"> <?php echo esc_html( $startnext_opt['loading_text'] ) ?> </p>
                            </div>
                        <?php endif;
                    elseif( $preloader_style == 'circle-spin' ) : ?>
                        <div class="preloader">
							<div class="spinner">
							</div>
						</div>
                    <?php else: ?>
                        <div class="preloader preloader-img">
                        </div>
                    <?php endif;
                endif;
            else:
                if ( $preloader_style == 'text' ) :
                    if (!empty( $startnext_opt['loading_text'] ) ) : ?>
                        <div class="preloader">
							<p class="text-center"> <?php echo esc_html( $startnext_opt['loading_text'] ) ?> </p>
                        </div>
                    <?php endif;
                elseif( $preloader_style == 'circle-spin' ) :
                    ?>
                    <div class="preloader">
						<div class="spinner">
						</div>
					</div>
                <?php else : ?>
                    <div class="preloader preloader-img">
                    </div>
                    <?php
                endif;
            endif;
        endif;
	}
endif;

if(function_exists('vc_disable_frontend')){
    vc_disable_frontend();
}

/**
 * Elementor post type support
 */
function startnext_add_cpt_support() {

    //if exists, assign to $cpt_support var
    $cpt_support = get_option( 'elementor_cpt_support' );

    //check if option DOESN'T exist in db
    if ( ! $cpt_support ) {
        $cpt_support = [ 'page', 'post', 'header', 'footer' ]; //create array of our default supported post types
        update_option( 'elementor_cpt_support', $cpt_support ); //write it to the database
    }
    //if it DOES exist, but header is NOT defined
    elseif ( !in_array( 'header', $cpt_support ) ) {
        $cpt_support[] = 'header'; //append to array
        update_option( 'elementor_cpt_support', $cpt_support ); //update database
    }
    //if it DOES exist, but footer is NOT defined
    elseif ( !in_array( 'footer', $cpt_support ) ) {
        $cpt_support[] = 'footer'; //append to array
        update_option( 'elementor_cpt_support', $cpt_support ); //update database
	}
}
add_action( 'after_switch_theme', 'startnext_add_cpt_support' );